FlutterWindowsIapPlatform class abstract

Inheritance
  • Object
  • PlatformInterface
  • FlutterWindowsIapPlatform
Implementers

Constructors

FlutterWindowsIapPlatform()
Constructs a FlutterWindowsIapPlatform.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

checkPurchase({required String storeId}) Future<bool>
getAddonLicenses() Future<Map<String, StoreLicense>>
getProducts(String storeId) Future<List<Product>>
getPurchaseId(String userId, {OneStoreConfig? config}) Future<Map<String, String>>
makePurchase(String storeId) Future<StorePurchaseStatus?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance FlutterWindowsIapPlatform
The default instance of FlutterWindowsIapPlatform to use.
getter/setter pair